@@ -1,8 +1,13 @@
 class Events:
     def __init__(self):
         self.events = []
+        self.custom_events = []
+
+        self.custom_events.append("on_command")
+        self.custom_events.append("on_command_error")
 
         self.events.append({"on_success": "authenticated"})
+        self.events.append({"on_ready": "authenticated"})
         self.events.append({"on_auth_error": "authentication_error"})
 
         self.events.append({"on_message": "message:created"})
@@ -82,4 +87,11 @@ class Events:
         for event in self.events:
             for key, value in event.items():
                 if value == event_value:
-                    return key
\ No newline at end of file
+                    return key
+
+    def is_valid_event(self, event_name):
+        for event in self.events:
+            for key, value in event.items():
+                if key == event_name:
+                    return True
+        return False
\ No newline at end of file
