@@ -8,4 +8,7 @@ from .server import *
 from .embed import *
 from .button import *
 from .member import *
-from .get import *
\ No newline at end of file
+from .get import *
+from .colour import *
+
+Color = Colour
\ No newline at end of file
