@@ -5,11 +5,11 @@ from . import extra
 
 class DMChannel:
     """
-    Nertivia DM Channel
-    Same as Text Channel but is used to send messages to a user.
+Nertivia DM Channel
+Same as Text Channel but is used to send messages to a user.
 
-    Attributes:
-        id (int): The ID of the channel.
+Attributes:
+- id (int): The ID of the channel.
     """
 
     def __init__(self, id) -> None: 
@@ -17,18 +17,18 @@ class DMChannel:
 
     def send(self, content = "", embed: embed.Embed = None, buttons: list = None) -> dict:
         """
-        Sends a message to the channel.
+Sends a message to the channel.
 
-        Args:
-            content (str): The content of the message.
-            embed (embed.Embed): The embed of the message.
-            buttons (list): The buttons of the message.
+Args:
+- content (str): The content of the message.
+- embed (embed.Embed): The embed of the message.
+- buttons (list): The buttons of the message.
 
-        Aliases:
-            send_message(content, embed, buttons)
-            
-        Returns:
-            dict: The response of the request.
+Aliases:
+- send_message(content, embed, buttons)
+
+Returns:
+- dict: The response of the request.
         """
 
         content = str(content)
